==> ZenTaoPMS.16.5.php7.2_7.4.zip: zentaopms/extension/max/cm/lang/zh-tw.php <==
<?php
$lang->cm->common        = '項目配置';
$lang->cm->delete        = '刪除基線';
$lang->cm->edit          = '編輯基線';
$lang->cm->browse        = '基線列表';
$lang->cm->report        = '配管報告';
$lang->cm->create        = '打基線';
$lang->cm->view          = '基線詳情';
$lang->cm->object        = '配置項名稱';
$lang->cm->title         = '配置項標識';
$lang->cm->from          = '評審版本';
$lang->cm->version       = '版本號';
$lang->cm->createdBy     = '由誰創建';
$lang->cm->createdDate   = '創建時間';
$lang->cm->noData        = '暫時沒有基線,';
$lang->cm->confirmDelete = '刪除該基線會同步刪除基線狀態報告中基線？';
$lang->cm->basicInfo     = '基本信息';

$lang->cm->baselineReport = '基線發佈報告';
$lang->cm->projectID      = '項目編號:';
$lang->cm->release        = '發佈形式:';
$lang->cm->approver       = '批准人:';
$lang->cm->projectName    = '項目名稱:';
$lang->cm->compiling      = '編製人:';
$lang->cm->changeDesc     = '基線發佈與變更描述';
$lang->cm->baselineID     = '序號';
$lang->cm->baselineTitle  = '基線項';
$lang->cm->reportRersion  = '版本號';
$lang->cm->releaseDate    = '發佈時間';
$lang->cm->authorized     = '批准人員';
$lang->cm->publisher      = '發佈人';
$lang->cm->baselineItem   = '基線';
$lang->cm->configItemName = '配置項名稱';
$lang->cm->configIdentify = '配置標識';
$lang->cm->currentVersion = '當前版本';
$lang->cm->configAdmin    = '配置管理員';
$lang->cm->solutionMan    = '解決人';
$lang->cm->confManagement = '配置管理';
$lang->cm->personnelQA    = 'QA人員';
$lang->cm->issueID        = '問題ID';
$lang->cm->issueDesc      = '問題描述';
$lang->cm->baselineAudit  = '發現問題的基線審計名稱';
$lang->cm->discoveryDate  = '發現時間';
$lang->cm->personLiable   = '責任人';
$lang->cm->proposedScheme = '建議解決方案';
$lang->cm->proposedDate   = '建議解決時間';
$lang->cm->solutionResult = '解決方法及結果';
$lang->cm->resolvingDate  = '解決時間';
$lang->cm->resolvingBy    = '解決人';
$lang->cm->currentState   = '當前狀態';
$lang->cm->resultQA       = 'QA檢查結果';

$lang->cm->auditItem['PP']     = 'plan';
$lang->cm->auditItem['SRS']    = 'story';
$lang->cm->auditItem['URS']    = 'story';
$lang->cm->auditItem['DDS']    = 'story';
$lang->cm->auditItem['HLDS']   = 'design';
$lang->cm->auditItem['ITTC']   = 'test';
$lang->cm->auditItem['ITP']    = 'test';
$lang->cm->auditItem['STP']    = 'test';
$lang->cm->auditItem['STTC']   = 'test';
$lang->cm->auditItem['manual'] = 'UM';
$lang->cm->auditItem['Code']   = 'project';
$lang->cm->auditItem['QAP']    = 'quality';
$lang->cm->auditItem['CMP']    = 'config';

$lang->cm->plan    = '計劃基線項';
$lang->cm->story   = '需求基線項';
$lang->cm->design  = '設計基線項';
$lang->cm->test    = '測試基線項';
$lang->cm->manual  = '手冊基線項';
$lang->cm->project = '程序基線項';
$lang->cm->quality = '質量基線項';
$lang->cm->config  = '配置基線項';
$lang->cm->custom  = '自定義基線項';

==> ZenTaoPMS-20.7.1-php7.1.zip: zentaopms/extension/max/cm/lang/zh-tw.php <==
<?php
$lang->cm->common        = $lang->projectCommon . '配置';
$lang->cm->delete        = '刪除基線';
$lang->cm->edit          = '編輯基線';
$lang->cm->browse        = '基線列表';
$lang->cm->report        = '配管報告';
$lang->cm->create        = '打基線';
$lang->cm->view          = '基線詳情';
$lang->cm->object        = '配置項名稱';
$lang->cm->title         = '配置項標識';
$lang->cm->from          = '評審版本';
$lang->cm->version       = '版本號';
$lang->cm->createdBy     = '由誰創建';
$lang->cm->createdDate   = '創建時間';
$lang->cm->noData        = '暫時沒有基線,';
$lang->cm->confirmDelete = '刪除該基線會同步刪除基線狀態報告中基線？';
$lang->cm->basicInfo     = '基本信息';

$lang->cm->baselineReport = '基線發佈報告';
$lang->cm->projectID      = $lang->projectCommon . '編號:';
$lang->cm->release        = '發佈形式:';
$lang->cm->approver       = '批准人:';
$lang->cm->projectName    = $lang->projectCommon . '名稱:';
$lang->cm->compiling      = '編製人:';
$lang->cm->changeDesc     = '基線發佈與變更描述';
$lang->cm->baselineID     = '序號';
$lang->cm->baselineTitle  = '基線項';
$lang->cm->reportRersion  = '版本號';
$lang->cm->releaseDate    = '發佈時間';
$lang->cm->authorized     = '批准人員';
$lang->cm->publisher      = '發佈人';
$lang->cm->baselineItem   = '基線';
$lang->cm->configItemName = '配置項名稱';
$lang->cm->configIdentify = '配置標識';
$lang->cm->currentVersion = '當前版本';
$lang->cm->configAdmin    = '配置管理員';
$lang->cm->solutionMan    = '解決人';
$lang->cm->confManagement = '配置管理';
$lang->cm->personnelQA    = 'QA人員';
$lang->cm->issueID        = '問題ID';
$lang->cm->issueDesc      = '問題描述';
$lang->cm->baselineAudit  = '發現問題的基線審計名稱';
$lang->cm->discoveryDate  = '發現時間';
$lang->cm->personLiable   = '責任人';
$lang->cm->proposedScheme = '建議解決方案';
$lang->cm->proposedDate   = '建議解決時間';
$lang->cm->solutionResult = '解決方案';
$lang->cm->resolvingDate  = '解決時間';
$lang->cm->resolvingBy    = '解決人';
$lang->cm->currentState   = '當前狀態';
$lang->cm->resultQA       = 'QA檢查結果';

$lang->cm->auditItem['PP']     = 'plan';
$lang->cm->auditItem['SRS']    = 'story';
$lang->cm->auditItem['URS']    = 'story';
$lang->cm->auditItem['DDS']    = 'story';
$lang->cm->auditItem['HLDS']   = 'design';
$lang->cm->auditItem['ITTC']   = 'test';
$lang->cm->auditItem['ITP']    = 'test';
$lang->cm->auditItem['STP']    = 'test';
$lang->cm->auditItem['STTC']   = 'test';
$lang->cm->auditItem['manual'] = 'UM';
$lang->cm->auditItem['Code']   = 'project';
$lang->cm->auditItem['QAP']    = 'quality';
$lang->cm->auditItem['CMP']    = 'config';

$lang->cm->plan    = '計劃基線項';
$lang->cm->story   = '需求基線項';
$lang->cm->design  = '設計基線項';
$lang->cm->test    = '測試基線項';
$lang->cm->manual  = '手冊基線項';
$lang->cm->project = '程序基線項';
$lang->cm->quality = '質量基線項';
$lang->cm->config  = '配置基線項';
$lang->cm->custom  = '自定義基線項';
